# Deltasimulator

[![Build Status](http://jenkins-riverlane.northeurope.cloudapp.azure.com/buildStatus/icon?job=deltasimulator_multibranch_build%2Fdev)](http://jenkins-riverlane.northeurope.cloudapp.azure.com/job/deltasimulator_multibranch_build/job/dev/)

Deltasimulator is a build system developed by Riverlane. The system can be
used to compile SystemC modules for nodes in a Deltaflow graph and wire the
nodes up. From there a complete runtime executable can be compiled, or the
graph can be connected to a larger platform representing physical devices
such as the ARTIQ platform via a Hardware Abstraction Layer (HAL).

Deltasimulator is a component of the Deltaflow-on-ARTIQ system, documentation
for this system and all it's components can be found
[here](https://riverlane.github.io/deltaflow-on-artiq).

## Quick Links

* [Documentation](https://riverlane.github.io/deltasimulator)

* [PyPI](https://pypi.org/project/deltasimulator)

* [GitHub](https://github.com/riverlane/deltasimulator)

* [Riverlane Website](https://www.riverlane.com/)

* [Official Deltaflow Discord](https://discord.gg/Gd2bYKvAeW)

## Contact Us

If you experience version incompatibilities, have feature requests or just want
to talk to our team about this project: send us an 
[email](mailto:deltaflow@riverlane.com).
